#[non_exhaustive]pub struct WebhookEvent {
pub sender: Option<Author>,
pub repository: Option<Repository>,
pub organization: Option<Organization>,
pub installation: Option<EventInstallation>,
pub kind: WebhookEventType,
pub specific: WebhookEventPayload,
}Expand description
A GitHub webhook event.
The structure is separated in common fields and specific fields, so you can always access the common values without needing to match the exact variant.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sender: Option<Author>repository: Option<Repository>organization: Option<Organization>installation: Option<EventInstallation>kind: WebhookEventTypespecific: WebhookEventPayloadImplementations
Sourceimpl WebhookEvent
impl WebhookEvent
Sourcepub fn try_from_header_and_body<B>(
header: &str,
body: &B,
) -> Result<WebhookEvent, Error>
pub fn try_from_header_and_body<B>( header: &str, body: &B, ) -> Result<WebhookEvent, Error>
Deserialize the body of a webhook event according to the category in the header of the request.