#[non_exhaustive]pub enum Event {
Show 53 variants
AddedToProject,
Assigned,
AutoMergeDisabled,
AutoMergeEnabled,
AutomaticBaseChangeFailed,
AutomaticBaseChangeSucceeded,
AutoRebaseEnabled,
AutoSquashEnabled,
BaseRefChanged,
BaseRefForcePushed,
Closed,
Commented,
CommentDeleted,
Committed,
Connected,
ConvertToDraft,
ConvertedNoteToIssue,
ConvertedToDiscussion,
CrossReferenced,
Demilestoned,
Deployed,
DeploymentEnvironmentChanged,
Disconnected,
HeadRefDeleted,
HeadRefForcePushed,
HeadRefRestored,
Labeled,
LineCommented,
Locked,
Mentioned,
MarkedAsDuplicate,
Merged,
Milestoned,
MovedColumnsInProject,
Pinned,
ReadyForReview,
Referenced,
RemovedFromProject,
Renamed,
Reopened,
ReviewDismissed,
ReviewRequested,
ReviewRequestRemoved,
Reviewed,
Subscribed,
Transferred,
Unassigned,
Unlabeled,
Unlocked,
UnmarkedAsDuplicate,
Unpinned,
Unsubscribed,
UserBlocked,
}Expand description
Issue events are triggered by activity in issues and pull requests. https://docs.github.com/en/webhooks-and-events/events/issue-event-types
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AddedToProject
The issue or pull request was added to a project board.
Assigned
The issue or pull request was assigned to a user.
AutoMergeDisabled
Auto merge was disabled for a pull request.
AutoMergeEnabled
Auto merge was enabled for a pull request.
AutomaticBaseChangeFailed
GitHub unsuccessfully attempted to automatically change the base branch of the pull request.
AutomaticBaseChangeSucceeded
GitHub successfully attempted to automatically change the base branch of the pull request.
AutoRebaseEnabled
Auto Rebase Enable
AutoSquashEnabled
Auto Squash Enable
BaseRefChanged
The base reference branch of the pull request changed.
BaseRefForcePushed
Not documented in the Github issue events documentation.
Closed
The issue or pull request was closed. When the commit_id is present, it identifies the commit that closed the issue using “closes / fixes” syntax.
Commented
A comment was added to the issue or pull request.
CommentDeleted
A comment that was removed from the issue or pull request. This isn’t documented as part of the issues-event-types API but returned by the API.
Committed
A commit was added to the pull request’s HEAD branch.
Connected
The issue or pull request was linked to another issue or pull request.
ConvertToDraft
The pull request was converted to draft mode.
ConvertedNoteToIssue
The issue was created by converting a note in a project board to an issue.
ConvertedToDiscussion
The issue was closed and converted to a discussion.
CrossReferenced
The issue or pull request was referenced from another issue or pull request.
Demilestoned
The issue or pull request was removed from a milestone.
Deployed
The pull request was deployed.
DeploymentEnvironmentChanged
The pull request deployment environment was changed.
Disconnected
The issue or pull request was unlinked from another issue or pull request.
HeadRefDeleted
The pull request’s HEAD branch was deleted.
HeadRefForcePushed
The pull request’s HEAD branch was force pushed.
HeadRefRestored
The pull request’s HEAD branch was restored to the last known commit.
Labeled
A label was added to the issue or pull request.
LineCommented
A comment on a line of source in a pull request. Not documented in the issue and events documentation.
Locked
The issue or pull request was locked.
Mentioned
The actor was @mentioned in an issue or pull request body.
MarkedAsDuplicate
A user with write permissions marked an issue as a duplicate of another issue, or a pull request as a duplicate of another pull request.
Merged
The pull request was merged. The commit_id attribute is the SHA1 of the HEAD commit that was merged. The commit_repository is always the same as the main repository.
Milestoned
The issue or pull request was added to a milestone.
MovedColumnsInProject
The issue or pull request was moved between columns in a project board.
Pinned
The issue was pinned.
ReadyForReview
A draft pull request was marked as ready for review.
Referenced
The issue was referenced from a commit message. The commit_id attribute is the commit SHA1 of where that happened and the commit_repository is where that commit was pushed.
RemovedFromProject
The issue or pull request was removed from a project board.
Renamed
The issue or pull request title was changed.
Reopened
The issue or pull request was reopened.
ReviewDismissed
The pull request review was dismissed.
ReviewRequested
A pull request review was requested.
ReviewRequestRemoved
A pull request review request was removed.
Reviewed
The pull request was reviewed.
Subscribed
Someone subscribed to receive notifications for an issue or pull request.
Transferred
The issue was transferred to another repository.
Unassigned
A user was unassigned from the issue.
Unlabeled
A label was removed from the issue.
Unlocked
The issue was unlocked.
UnmarkedAsDuplicate
An issue that a user had previously marked as a duplicate of another issue is no longer considered a duplicate, or a pull request that a user had previously marked as a duplicate of another pull request is no longer considered a duplicate.
Unpinned
The issue was unpinned.
Unsubscribed
Someone unsubscribed from receiving notifications for an issue or pull request.
UserBlocked
An organization owner blocked a user from the organization.